window.Gleam.initSearch([{"doc":"finch_gleam","title":"finch_gleam","content":"# finch_gleam\n\n[![Package Version](https://img.shields.io/hexpm/v/finch_gleam)](https://hex.pm/packages/finch_gleam)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/finch_gleam/)\n\nA wrapper/adapter package for the [Finch](https://hexdocs.pm/finch) HTTP client.\n\nThis library adapts the Finch functions to accept and return [gleam/http](https://hexdocs.pm/gleam_http) requests and responses.\n\n## Installation\n\nThis package can be added to your Gleam project:\n\n```sh\ngleam add finch_gleam\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/finch_gleam&gt;.\n\n## Usage\n\n```gleam\nimport gleam/uri\nimport gleam/http\nimport gleam/http/request\nimport gleam/erlang/atom\nimport finch\n\nassert Ok(url) = uri.parse(&quot;https://example.com/&quot;)\nassert Ok(req) = request.from_uri(url)\nlet req = request.Request(..req, method: http.Post, body: &quot;foo bar&quot;)\n\n// Build Finch request from gleam/http request\nlet finch_req = finch.build(req, [])\n\n// Run request with Finch, using Finch.Server, returns gleam/http response\nassert Ok(resp) = finch.request(finch_req, atom.create_from_string(&quot;Elixir.Finch.Server&quot;))\n```\n","url":"index.html"},{"doc":"finch/headers","title":"Header","content":"pub type Header =\n  #(String, String)\n\n\nSynonyms:\nfinch/headers.Header\nfinch/headers Header","url":"finch/headers.html#Header"},{"doc":"finch/headers","title":"Headers","content":"pub type Headers =\n  List(Header)\n\n\nSynonyms:\nfinch/headers.Headers\nfinch/headers Headers","url":"finch/headers.html#Headers"},{"doc":"finch/headers","title":"finch/headers","content":"","url":"finch/headers.html"},{"doc":"finch/stream","title":"StreamBlock","content":"pub type StreamBlock {\n  Status(status: Int)\n  Headers(headers: ReqHeaders)\n  Data(data: BitString)\n}\n A block of data sent by Finch from the HTTP request stream.\nStatus(status: Int)\n\n\nHeaders(headers: ReqHeaders)\n\n\nData(data: BitString)\n\n\nSynonyms:\nfinch/stream.StreamBlock\nfinch/stream StreamBlock","url":"finch/stream.html#StreamBlock"},{"doc":"finch/stream","title":"StreamFun","content":"pub type StreamFun(a) =\n  fn(StreamBlock, a) -&gt; a\n A stream handler function\n\n Receives a block of the stream data as the first argument and the\n accumulator as the second, must return the accumulator.\n\nSynonyms:\nfinch/stream.StreamFun\nfinch/stream StreamFun","url":"finch/stream.html#StreamFun"},{"doc":"finch/stream","title":"finch/stream","content":"","url":"finch/stream.html"},{"doc":"finch/timeout","title":"Timeout","content":"pub external type Timeout\n A timeout value, either infinite or a specified amount of milliseconds.\n\nSynonyms:\nfinch/timeout.Timeout\nfinch/timeout Timeout","url":"finch/timeout.html#Timeout"},{"doc":"finch/timeout","title":"infinity","content":"pub fn infinity() -&gt; Timeout\n Create an infinite timeout.\nSynonyms:\nfinch/timeout.infinity\nfinch/timeout infinity","url":"finch/timeout.html#infinity"},{"doc":"finch/timeout","title":"milliseconds","content":"pub fn milliseconds(ms: Int) -&gt; Timeout\n Create a timeout with the given milliseconds.\nSynonyms:\nfinch/timeout.milliseconds\nfinch/timeout milliseconds","url":"finch/timeout.html#milliseconds"},{"doc":"finch/timeout","title":"finch/timeout","content":" Wrapper of Elixir&#39;s `timeout/0` type.\n\n See [https://hexdocs.pm/elixir/typespecs.html#built-in-types](https://hexdocs.pm/elixir/typespecs.html#built-in-types)\n for a specification of the type.","url":"finch/timeout.html"},{"doc":"finch/otp","title":"InstanceOption","content":"pub type InstanceOption {\n  Name(Atom)\n  Pools(Map(PoolSpecifier, PoolOptions))\n}\n\nName(Atom)\n\n\nPools(Map(PoolSpecifier, PoolOptions))\n\n\nSynonyms:\nfinch/otp.InstanceOption\nfinch/otp InstanceOption","url":"finch/otp.html#InstanceOption"},{"doc":"finch/otp","title":"InstanceOptions","content":"pub type InstanceOptions =\n  List(InstanceOption)\n\n\nSynonyms:\nfinch/otp.InstanceOptions\nfinch/otp InstanceOptions","url":"finch/otp.html#InstanceOptions"},{"doc":"finch/otp","title":"OnStart","content":"pub type OnStart {\n  Ok(child: Pid)\n  Ignore\n  Error(Dynamic)\n}\n Returned by `start_link/2`.\n\n Note that this is not the same as Gleam&#39;s standard `Result` type! You will\n need to match this manually, it cannot be used with `try` syntax.\nOk(child: Pid)\n\n\nIgnore\n\n\nError(Dynamic)\n\n\nSynonyms:\nfinch/otp.OnStart\nfinch/otp OnStart","url":"finch/otp.html#OnStart"},{"doc":"finch/otp","title":"PoolOption","content":"pub type PoolOption {\n  Protocol(PoolProtocol)\n  Size(Int)\n  Count(Int)\n  MaxIdleTime(Timeout)\n  ConnOpts(List(#(Atom, Dynamic)))\n  PoolMaxIdleTime(Timeout)\n  ConnMaxIdleTime(Timeout)\n}\n\nProtocol(PoolProtocol)\n\n\nSize(Int)\n\n\nCount(Int)\n\n\nMaxIdleTime(Timeout)\n\n\nConnOpts(List(#(Atom, Dynamic)))\n\n\nPoolMaxIdleTime(Timeout)\n\n\nConnMaxIdleTime(Timeout)\n\n\nSynonyms:\nfinch/otp.PoolOption\nfinch/otp PoolOption","url":"finch/otp.html#PoolOption"},{"doc":"finch/otp","title":"PoolOptions","content":"pub type PoolOptions =\n  List(PoolOption)\n\n\nSynonyms:\nfinch/otp.PoolOptions\nfinch/otp PoolOptions","url":"finch/otp.html#PoolOptions"},{"doc":"finch/otp","title":"PoolProtocol","content":"pub type PoolProtocol {\n  Http1\n  Http2\n}\n\nHttp1\n\n\nHttp2\n\n\nSynonyms:\nfinch/otp.PoolProtocol\nfinch/otp PoolProtocol","url":"finch/otp.html#PoolProtocol"},{"doc":"finch/otp","title":"PoolSpecifier","content":"pub type PoolSpecifier {\n  Default\n  URL(url: uri.Uri)\n  UnixSocket(specifier: UnixSocketSpecifier)\n}\n\nDefault\n\n\nURL(url: uri.Uri)\n\n\nUnixSocket(specifier: UnixSocketSpecifier)\n\n\nSynonyms:\nfinch/otp.PoolSpecifier\nfinch/otp PoolSpecifier","url":"finch/otp.html#PoolSpecifier"},{"doc":"finch/otp","title":"UnixSocketPath","content":"pub type UnixSocketPath {\n  Local(path: String)\n}\n\nLocal(path: String)\n\n\nSynonyms:\nfinch/otp.UnixSocketPath\nfinch/otp UnixSocketPath","url":"finch/otp.html#UnixSocketPath"},{"doc":"finch/otp","title":"UnixSocketSpecifier","content":"pub type UnixSocketSpecifier {\n  Http(path: UnixSocketPath)\n  Https(path: UnixSocketPath)\n}\n\nHttp(path: UnixSocketPath)\n\n\nHttps(path: UnixSocketPath)\n\n\nSynonyms:\nfinch/otp.UnixSocketSpecifier\nfinch/otp UnixSocketSpecifier","url":"finch/otp.html#UnixSocketSpecifier"},{"doc":"finch/otp","title":"finch/otp","content":" Types related to OTP usage of Finch.","url":"finch/otp.html"},{"doc":"finch","title":"Exception","content":"pub external type Exception\n Exception returned by Finch in case of request errors.\n\nSynonyms:\nfinch.Exception\nfinch Exception","url":"finch.html#Exception"},{"doc":"finch","title":"Request","content":"pub external type Request\n Finch request, use `build/2` to create one from a Gleam request.\n\nSynonyms:\nfinch.Request\nfinch Request","url":"finch.html#Request"},{"doc":"finch","title":"RequestOption","content":"pub type RequestOption {\n  PoolTimeout(ms: Int)\n  RequestTimeout(ms: Int)\n}\n\nPoolTimeout(ms: Int)\n\n\nRequestTimeout(ms: Int)\n\n\nSynonyms:\nfinch.RequestOption\nfinch RequestOption","url":"finch.html#RequestOption"},{"doc":"finch","title":"RequestOptions","content":"pub type RequestOptions =\n  List(RequestOption)\n\n\nSynonyms:\nfinch.RequestOptions\nfinch RequestOptions","url":"finch.html#RequestOptions"},{"doc":"finch","title":"build","content":"pub fn build(req: Request(String), opts: List(RequestOption)) -&gt; finch.Request\n Build a Finch request that can be run with `request/2` or `stream/5`.\n\n Note, the HTTP methods CONNECT, TRACE, and `Other(String)` are not\n supported, and will be converted to GET.\nSynonyms:\nfinch.build\nfinch build","url":"finch.html#build"},{"doc":"finch","title":"request","content":"pub fn request(req: Request, name: Atom) -&gt; Result(\n  Response(String),\n  Exception,\n)\n Send a request using the Finch instance with the given name.\nSynonyms:\nfinch.request\nfinch request","url":"finch.html#request"},{"doc":"finch","title":"start_link","content":"pub external fn start_link(opts: InstanceOptions) -&gt; OnStart\n Start a new Finch instance with the given options.\nSynonyms:\nfinch.start_link\nfinch start_link","url":"finch.html#start_link"},{"doc":"finch","title":"stream","content":"pub external fn stream(\n  req: Request,\n  name: Atom,\n  acc: a,\n  fun: StreamFun(a),\n  opts: RequestOptions,\n) -&gt; Result(a, Exception)\n Stream a request using the Finch instance with the given name.\nSynonyms:\nfinch.stream\nfinch stream","url":"finch.html#stream"},{"doc":"finch","title":"finch","content":" Finch API wrapper module.\n\n See the [Finch documentation](https://hexdocs.pm/finch) for additional\n information about the functions.","url":"finch.html"}]);